sessions.Session (session) — amici1

# `sessions.Session` (session)

Django provides full support for anonymous sessions. The session framework lets you store and retrieve arbitrary data on a per-site-visitor basis. It stores data on the server side and abstracts the sending and receiving of cookies. Cookies contain a session ID – not the data itself.

The Django sessions framework is entirely cookie-based. It does not fall back to putting session IDs in URLs. This is an intentional design decision. Not only does that behavior make URLs ugly, it makes your site vulnerable to session-ID theft via the “Referer” header.

For complete documentation on using Sessions in your code, consult the sessions documentation that is shipped with Django (also available on the Django Web site).

Master tables : users.Sessions (User sessions)

Database fields:

- session key (session_key) : See `<django.db.models.fields.CharField: session_key>`.

- session data (session_data) : See `<django.db.models.fields.TextField: session_data>`.

- expire date (expire_date) : See `<django.db.models.fields.DateTimeField: expire_date>`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

Referenced from

## Database fields

Internal name | Verbose name | Help text
session_key | session key |
session_data | session data |
expire_date | expire date |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.